/*
 *  ----------------------------------------------------------------------------
 *  Filename      : Control.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 08.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComboBox;
import javax.swing.JFileChooser;

import ch.educeth.soekia.util.StringConstants;

/**
 * Control.
 *
 * @author	Matthias Dreier
 */
public class Control implements ActionListener {

	/**
	 * The application.
	 */
	protected Application app;

	/**
	 * The file chooser for the open and save dialogs.
	 */
	protected JFileChooser fileChooser;

	/**
	 * Creates a new control instance for the given application.
	 *
	 * @param	application		The application.
	 */
	public Control(Application application) {
		app = application;

		fileChooser = new JFileChooser();
	}

	public void actionPerformed(ActionEvent e) {
		String action = e.getActionCommand();

		if (action.equals("about")) {
			app.showAboutDialog();
		} else if (action.equals("help")) {
			app.showHelpWindow();
		} else if (action.equals("open")) {
			fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
			if (fileChooser.showDialog(app, StringConstants.getString(StringConstants.BROWSE_LABEL)) == JFileChooser.APPROVE_OPTION) {
				app.setIndexDirectory(fileChooser.getSelectedFile());
			}
		} else if (action.equals("document")) {
			fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
			if (fileChooser.showDialog(app, StringConstants.getString(StringConstants.BROWSE_LABEL)) == JFileChooser.APPROVE_OPTION) {
				app.setDocumentDirectory(fileChooser.getSelectedFile());
			}
		} else if (action.equals("language")) {
			app.setLanguage(((JComboBox)e.getSource()).getSelectedIndex());
		} else if (action.equals("stemming")) {
			app.setStemming(((JComboBox)e.getSource()).getSelectedIndex());
		} else if (action.equals("stopWord")) {
			app.setStopWord(((JComboBox)e.getSource()).getSelectedIndex());
		} else if (action.equals("create")) {
			app.createIndex();
		} else if (action.equals("show")) {
			app.showIndex();
		} else if (action.equals("search")) {
			app.search();
		} else if (action.startsWith("radio")) {
			app.setRanking(action);
		}
	}

}
