/*
 *  ----------------------------------------------------------------------------
 *  Filename      : IndexThread.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 11.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.index;

import java.io.File;

import org.apache.lucene.demo.HTMLDocument;
import org.apache.lucene.document.Document;

import ch.educeth.soekia.Application;

/**
 * The thread that creates the index.
 *
 * @author	Matthias Dreier
 */
public class IndexThread {

	/**
	 * The application for this thread.
	 */
	protected Application application;

	/**
	 * The index task for this thread.
	 */
	protected IndexTask task;

	/**
	 * Creates a new IndexThread for the given application.
	 *
	 * @param	application		The application.
	 * @param	task			The index task.
	 */
	public IndexThread(Application application, IndexTask task) {
		this.application = application;
		this.task = task;
		createIndex();
	}

	/**
	 * Creates the index.
	 */
	public void createIndex() {
		int size = application.fileVector.size();
		for (int i = 0; i < size; i++) {
			File file = (File)application.fileVector.get(i);
			try {
				Document doc = HTMLDocument.Document(file);
				task.status = doc.get("url");
				application.indexWriter.addDocument(doc);
			} catch (Exception ex) {
				ex.printStackTrace(System.err);
			}
			task.current = 100*(i + 1)/size;
			if (application.indexCanceled) {
				task.current = 100;
				return;
			}
		}
		application.saveSettings();
	}

}
