/*
 *  ----------------------------------------------------------------------------
 *  Filename      : EnglishAnalyzer.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 11.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.lucene;

import java.io.Reader;
import java.util.Hashtable;
import java.util.StringTokenizer;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.LowerCaseFilter;
import org.apache.lucene.analysis.PorterStemFilter;
import org.apache.lucene.analysis.StopFilter;
import org.apache.lucene.analysis.TokenStream;
import org.apache.lucene.analysis.standard.StandardFilter;
import org.apache.lucene.analysis.standard.StandardTokenizer;

/**
 * EnglishAnalyzer.
 *
 * @author	Matthias Dreier
 */
public class EnglishAnalyzer extends Analyzer {

	/**
	 * The flag whether to do stemming.
	 */
	protected boolean doStemming;

	/**
	 * The flag whether to remove the stop words.
	 */
	protected boolean removeStopWords;

	/**
	 * The table containing the stop words.
	 */
	protected Hashtable stopTable;

	/**
	 * Creates a new EnglishAnalyzer.
	 *
	 * @param	doStemming			The flag whether to do stemming.
	 * @param	removeStopWords		The flag whether to remove the stop words.
	 * @param	stopWords			The string containing the stop words.
	 */
	public EnglishAnalyzer(boolean doStemming, boolean removeStopWords, String stopWords) {
		this.doStemming = doStemming;
		this.removeStopWords = removeStopWords;

		stopTable = new Hashtable();
		StringTokenizer tokenizer = new StringTokenizer(stopWords);
		while (tokenizer.hasMoreTokens()) {
			String word = tokenizer.nextToken();
			stopTable.put(word, word);
		}
	}

	public TokenStream tokenStream(String fieldName, Reader reader) {
		TokenStream result = new StandardTokenizer(reader);
		result = new StandardFilter(result);
		result = new LowerCaseFilter(result);
		if (removeStopWords) {
			result = new StopFilter(result, stopTable);
		}
		if (doStemming) {
			result = new PorterStemFilter(result);
		}

		return result;
	}

}
