/*
 *  ----------------------------------------------------------------------------
 *  Filename      : UmlautFilter.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 30.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.lucene;

import java.io.IOException;

import org.apache.lucene.analysis.Token;
import org.apache.lucene.analysis.TokenFilter;
import org.apache.lucene.analysis.TokenStream;

/**
 * UmlautFilter.
 *
 * @author	Matthias Dreier
 */
public class UmlautFilter extends TokenFilter {

	/**
	 * Creates a new umlaut filter for the given token stream.
	 *
	 * @param	in	The token stream.
	 */
	public UmlautFilter(TokenStream in) {
		input = in;
	}

	public Token next() throws IOException {
		Token t = input.next();
		if (t == null) {
			return null;
		}

		String text = t.termText();

		// Remove diaereses
		text = text.replace('', 'a');
		text = text.replace('', 'o');
		text = text.replace('', 'u');

		// Remove Esszetts
		while (text.indexOf('') != -1) {
			text = text.substring(0, text.indexOf('')) + "ss" + text.substring(text.indexOf('') + 1);
		}

		return new Token(text, t.startOffset(), t.endOffset(), t.type());
	}

}
