/*
 *  ----------------------------------------------------------------------------
 *  Filename      : StringConstants.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 07.10.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.util;

import java.text.MessageFormat;
import java.util.Properties;

/**
 * StringConstants.
 *
 * @author	Matthias Dreier
 */
public abstract class StringConstants {

	/*
	 * Language-independent string constants
	 */
	public final static String ENGLISH = "English";
	public final static String GERMAN = "German";
	public final static String INDEX_DIRECTORY_NAME = "soekia-index";
	public final static String INDEX_FILE_NAME = "soekia-index.xml";
	public final static String INDEX_FILE_PREFIX = "soekia-index-";
	public final static String INDEX_FILE_SUFFIX = ".html";
	public final static String RESULT_FILE_PREFIX = "soekia-result-";
	public final static String RESULT_FILE_SUFFIX = ".html";

	/**
	 * List of the 50 most frequent English and German words
	 * (according to http://wortschatz.uni-leipzig.de/html/wliste.html).
	 */
	public static final String[] STOP_WORDS = {
	  "a about also an and are as at be been but by can for from had has have he his in is it its million more new not of on one or other said than that the their they this to up was were which who will with would you",
	  "aber als am an auch auf aus bei das dass dem den der des die ein eine einem einen einer er es fur haben hat im in ist mit nach nicht noch nur oder sich sie sind so uber um und von vor war werden wie wird zu zum zur"
	};

	/*
	 * The keys of the properties.
	 */
	public final static String ABOUT_TITLE = "about-title";
	public final static String ABOUT_TOOLTIP = "about-tooltip";
	public final static String APPLICATION_TITLE = "application-title";
	public final static String BROWSE_LABEL = "browse-label";
	public final static String CANCEL_LABEL = "cancel-label";
	public final static String CREATE_INDEX_LABEL = "create-index-label";
	public final static String CREATING_INDEX_LABEL = "creating-index-label";
	public final static String DEACTIVATED_LABEL = "deactivated-label";
	public final static String DOCUMENT_COLLECTION_LABEL = "document-collection-label";
	public final static String DOCUMENTS_FOUND_LABEL = "documents-found-label";
	public final static String DOCUMENTS_LABEL = "documents-label";
	public final static String DOCUMENTS_PLURAL_LABEL = "documents-plural-label";
	public final static String DONT_CARE_LABEL = "dont-care-label";
	public final static String ERROR_LABEL = "error-label";
	public final static String FREQUENCY_LABEL = "frequency-label";
	public final static String GPL_FILE = "gpl-file";
	public final static String GPL_LABEL = "gpl-label";
	public final static String HELP_LABEL = "help-label";
	public final static String ICON_FILE = "icon-file";
	public final static String INCLUDE_SUBDIRECTORIES_LABEL = "include-subdirectories-label";
	public final static String INDEX_CREATION_LABEL = "index-creation-label";
	public final static String INDEX_LABEL = "index-label";
	public final static String INDEX_LOCATION_LABEL = "index-location-label";
	public final static String INDEX_PARAMETERS_LABEL = "index-parameters-label";
	public final static String LANGUAGE = "language";
	public final static String LANGUAGE_ENGLISH = "language-english";
	public final static String LANGUAGE_GERMAN = "language-german";
	public final static String LANGUAGE_LABEL = "language-label";
	public final static String LINGUISTIC_LABEL = "linguistic-label";
	public final static String NO_DOCUMENTS_LABEL = "no-documents-label";
	public final static String NO_HTML_FILES_LABEL = "no-html-files-label";
	public final static String NO_INDEX_DISPLAY_LABEL = "no-index-display-label";
	public final static String NO_INDEX_LABEL = "no-index-label";
	public final static String NORMAL_LABEL = "normal-label";
	public final static String NOT_ENOUGH_MEMORY_INDEX_LABEL = "not-enough-memory-index-label";
	public final static String NOT_ENOUGH_MEMORY_LABEL = "not-enough-memory-label";
	public final static String OK_LABEL = "ok-label";
	public final static String OVERWRITE_INDEX_LABEL = "overwrite-index-label";
	public final static String OVERWRITE_LABEL = "overwrite-label";
	public final static String PREDEFINED_LIST_LABEL = "predefined-list-label";
	public final static String QUERY_ILLEGAL_LABEL = "query-illegal-label";
	public final static String QUERY_LABEL = "query-label";
	public final static String RANKING_PRINCIPLE_1_TOOLTIP = "ranking-principle-1-tooltip";
	public final static String RANKING_PRINCIPLE_2_TOOLTIP = "ranking-principle-2-tooltip";
	public final static String RANKING_PRINCIPLE_3_TOOLTIP = "ranking-principle-3-tooltip";
	public final static String RANKING_PRINCIPLE_LABEL = "ranking-principle-label";
	public final static String RESULT_LABEL = "result-label";
	public final static String SEARCH_LABEL = "search-label";
	public final static String SHOW_INDEX_LABEL = "show-index-label";
	public final static String SOEKIA_HELP_FILE = "soekia-help-file";
	public final static String SOEKIA_LABEL = "soekia-label";
	public final static String SPECIFY_LABEL = "specify-label";
	public final static String SPLASH_FILE = "splash-file";
	public final static String STEMMING_LABEL = "stemming-label";
	public final static String STOP_WORDS_LABEL = "stop-words-label";
	public final static String STOP_WORDS_TITLE = "stop-words-title";
	public final static String STRONG_LABEL = "strong-label";
	public final static String TERM_LABEL = "term-label";
	public final static String TOTAL_LABEL = "total-label";
	public final static String TOTAL_TERMS_LABEL = "total-terms-label";
	public final static String USER_INTERFACE_HELP_FILE = "user-interface-help-file";
	public final static String USER_INTERFACE_LABEL = "user-interface-label";
	public final static String WARNING_LABEL = "warning-label";
	public final static String WEAK_LABEL = "weak-label";

	/**
	 * The string properties.
	 */
	protected static Properties strings;

	/**
	 * Initializes the StringConstants class for the given language.
	 *
	 * @param	language	The language.
	 */
	public static void initialize(String language) {
		strings = new Properties();
		try {
			strings.load(ClassLoader.getSystemResourceAsStream("ch/educeth/soekia/resources/strings_" + language + ".txt"));
		} catch (Exception ex) {
			ex.printStackTrace(System.out);
		}
	}

	/**
	 * Returns the string for the given property. The StringConstants class must
	 * be initialized before the first invokation of this method.
	 *
	 * @param	key		The key of the property.
	 *
	 * @return			The string for the given property or <code>null</code>
	 * 					if the property does not exist.
	 */
	public static String getString(String key) {
		return strings.getProperty(key);
	}

	/**
	 * Returns the string for the given property and inserts the given
	 * arguments. The StringConstants class must be initialized before the first
	 * invokation of this method.
	 *
	 * @param	key		The key of the property.
	 * @param	args	The arguments to insert.
	 *
	 * @return			The string for the given property or the empty string
	 * 					if the property does not exist.
	 */
	public static String getString(String key, Object[] args) {
		String result = strings.getProperty(key);
		if (result == null) {
			result = "";
		}
		result = MessageFormat.format(result, args);

		return result;
	}

}
