/*
 *  ----------------------------------------------------------------------------
 *  Filename      : Settings.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 16.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.xml;

import java.util.ArrayList;

/**
 * A list of settings.
 * 
 * @author	Matthias Dreier
 */
public class Settings {

	/**
	 * The list of settings.
	 */
	protected ArrayList settings;

	/**
	 * The name of the settings.
	 */
	protected String name;

	/**
	 * Creates a new settings object.
	 *
	 * @param	name	The name of the settings.
	 */
	public Settings(String name) {
		settings = new ArrayList();
		this.name = name;
	}

	/**
	 * Adds the given setting to the list.
	 *
	 * @param	setting		The setting.
	 */
	public void addSetting(Setting setting) {
		settings.add(setting);
	}

	/**
	 * Returns the setting at the given position in the list.
	 *
	 * @param	index	The index of the setting in the list.
	 *
	 * @return			The setting at the given position in the list or
	 * 					<code>null</code> if the setting does not exist.
	 */
	public Setting getSetting(int index) {
		if (index < settings.size()) {
			return (Setting)settings.get(index);
		} else {
			return null;
		}
	}

	/**
	 * Returns the number of settings in the list.
	 *
	 * @return		The number of settings in the list.
	 */
	public int getNumberSettings() {
		return settings.size();
	}

	/**
	 * Returns the name of the settings.
	 *
	 * @return		The name of the settings.
	 */
	public String getName() {
		return name;
	}

}
