/*
 *  ----------------------------------------------------------------------------
 *  Filename      : XmlImporter.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 16.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.xml;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

/**
 * An XML importer for settings.
 * 
 * @author	Matthias Dreier
 */
public class XmlImporter {

	/**
	 * Imports the settings from the given file.
	 *
	 * @param	file	The file.
	 *
	 * @return			The imported settings or <code>null</code> if an error
	 * 					occurred.
	 */
	public Settings importSettings(File file) {
		try {
			BufferedReader br = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8"));
			String line = br.readLine();
			while (!line.startsWith("  <name>")) {
				line = br.readLine();
			}
			Settings settings = new Settings(line.substring(line.indexOf(">") + 1, line.lastIndexOf("<")));

			line = br.readLine();
			while (line.startsWith("  <setting>")) {
				settings.addSetting(readSetting(br));
				line = br.readLine();
			}

			br.close();
			return settings;
		} catch (Exception ex) {
			return null;
		}
	}

	/**
	 * Reads a setting from the given BufferedReader.
	 *
	 * @param	br				The BufferedReader.
	 *
	 * @return					The setting read from the BufferedReader.
	 *
	 * @throws	IOException		Any exception that occured.
	 */
	protected Setting readSetting(BufferedReader br) throws IOException {
		ArrayList list = new ArrayList();
		String line;
		String name;
		String value;
		Setting setting;

		line = br.readLine();
		while (!line.startsWith("    <name>")) {
			line = br.readLine();
		}
		name = line.substring(line.indexOf(">") + 1, line.lastIndexOf("<"));

		line = br.readLine();
		while (line.startsWith("    <value>")) {
			value = line.substring(line.indexOf(">") + 1, line.lastIndexOf("<"));
			list.add(value);
			line = br.readLine();
		}

		setting = new Setting(name, list);

		return setting;
	}

}
